==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/WebComponentDataValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentDataValueChangedEventArgsDescription } from "./WebComponentDataValueChangedEventArgsDescription";
/**
 * @hidden
 */
var WebComponentDataValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebComponentDataValueChangedEventArgsDescriptionMetadata, _super);
    function WebComponentDataValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebComponentDataValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (WebComponentDataValueChangedEventArgsDescriptionMetadata.a == null) {
            WebComponentDataValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebComponentDataValueChangedEventArgsDescriptionMetadata.c(WebComponentDataValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebComponentDataValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebComponentDataValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentDataValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ComponentDataValueChangedEventArgs");
        a.item("Detail", "Unknown");
    };
    WebComponentDataValueChangedEventArgsDescriptionMetadata.d = function (a) {
        WebComponentDataValueChangedEventArgsDescriptionMetadata.b(a);
        a.u("WebComponentDataValueChangedEventArgs", function () { return new WebComponentDataValueChangedEventArgsDescription(); });
        a.t("WebComponentDataValueChangedEventArgs", WebComponentDataValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentDataValueChangedEventArgsDescriptionMetadata.$t = markType(WebComponentDataValueChangedEventArgsDescriptionMetadata, 'WebComponentDataValueChangedEventArgsDescriptionMetadata');
    WebComponentDataValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentDataValueChangedEventArgsDescriptionMetadata;
}(Base));
export { WebComponentDataValueChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebComponentDataValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentDataValueChangedEventArgsDescription } from "./WebComponentDataValueChangedEventArgsDescription";
/**
 * @hidden
 */
var WebComponentDataValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebComponentDataValueChangedEventArgsDescriptionMetadata, _super);
    function WebComponentDataValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebComponentDataValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (WebComponentDataValueChangedEventArgsDescriptionMetadata.a == null) {
            WebComponentDataValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebComponentDataValueChangedEventArgsDescriptionMetadata.c(WebComponentDataValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebComponentDataValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebComponentDataValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentDataValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ComponentDataValueChangedEventArgs");
        a.item("Detail", "Unknown");
    };
    WebComponentDataValueChangedEventArgsDescriptionMetadata.d = function (a) {
        WebComponentDataValueChangedEventArgsDescriptionMetadata.b(a);
        a.aa("WebComponentDataValueChangedEventArgs", function () { return new WebComponentDataValueChangedEventArgsDescription(); });
        a.z("WebComponentDataValueChangedEventArgs", WebComponentDataValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentDataValueChangedEventArgsDescriptionMetadata.$t = markType(WebComponentDataValueChangedEventArgsDescriptionMetadata, 'WebComponentDataValueChangedEventArgsDescriptionMetadata');
    WebComponentDataValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentDataValueChangedEventArgsDescriptionMetadata;
}(Base));
export { WebComponentDataValueChangedEventArgsDescriptionMetadata };
